from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.math import *
from OCC.Core.gp import *
from OCC.Core.IntSurf import *
from OCC.Core.Adaptor3d import *
from OCC.Core.Adaptor2d import *
from OCC.Core.GeomAbs import *
from OCC.Core.Geom2d import *
from OCC.Core.TColStd import *


class Contap_SequenceOfIWLineOfTheIWalking:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Contap_SequenceOfPathPointOfTheSearch:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Contap_ThePathPointOfTheSearch: ...
    def Last(self) -> Contap_ThePathPointOfTheSearch: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Contap_ThePathPointOfTheSearch) -> Contap_ThePathPointOfTheSearch: ...
    def Prepend(self, theItem: Contap_ThePathPointOfTheSearch) -> Contap_ThePathPointOfTheSearch: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Contap_ThePathPointOfTheSearch: ...
    def SetValue(self, theIndex: int, theValue: Contap_ThePathPointOfTheSearch) -> None: ...

class Contap_SequenceOfSegmentOfTheSearch:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Contap_TheSegmentOfTheSearch: ...
    def Last(self) -> Contap_TheSegmentOfTheSearch: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Contap_TheSegmentOfTheSearch) -> Contap_TheSegmentOfTheSearch: ...
    def Prepend(self, theItem: Contap_TheSegmentOfTheSearch) -> Contap_TheSegmentOfTheSearch: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Contap_TheSegmentOfTheSearch: ...
    def SetValue(self, theIndex: int, theValue: Contap_TheSegmentOfTheSearch) -> None: ...

class Contap_TheSequenceOfLine:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Contap_Line: ...
    def Last(self) -> Contap_Line: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Contap_Line) -> Contap_Line: ...
    def Prepend(self, theItem: Contap_Line) -> Contap_Line: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Contap_Line: ...
    def SetValue(self, theIndex: int, theValue: Contap_Line) -> None: ...

class Contap_TheSequenceOfPoint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Contap_Point: ...
    def Last(self) -> Contap_Point: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Contap_Point) -> Contap_Point: ...
    def Prepend(self, theItem: Contap_Point) -> Contap_Point: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Contap_Point: ...
    def SetValue(self, theIndex: int, theValue: Contap_Point) -> None: ...

class Contap_IType(IntEnum):
	Contap_Lin: int = ...
	Contap_Circle: int = ...
	Contap_Walking: int = ...
	Contap_Restriction: int = ...
Contap_Lin = Contap_IType.Contap_Lin
Contap_Circle = Contap_IType.Contap_Circle
Contap_Walking = Contap_IType.Contap_Walking
Contap_Restriction = Contap_IType.Contap_Restriction

class Contap_TFunction(IntEnum):
	Contap_ContourStd: int = ...
	Contap_ContourPrs: int = ...
	Contap_DraftStd: int = ...
	Contap_DraftPrs: int = ...
Contap_ContourStd = Contap_TFunction.Contap_ContourStd
Contap_ContourPrs = Contap_TFunction.Contap_ContourPrs
Contap_DraftStd = Contap_TFunction.Contap_DraftStd
Contap_DraftPrs = Contap_TFunction.Contap_DraftPrs

class Contap_ArcFunction(math_FunctionWithDerivative):
	def __init__(self) -> None: ...
	def Derivative(self, X: float) -> Tuple[bool, float]: ...
	def GetStateNumber(self) -> int: ...
	def LastComputedPoint(self) -> gp_Pnt: ...
	def NbSamples(self) -> int: ...
	def Quadric(self) -> IntSurf_Quadric: ...
	@overload
	def Set(self, S: Adaptor3d_HSurface) -> None: ...
	@overload
	def Set(self, Direction: gp_Dir) -> None: ...
	@overload
	def Set(self, Direction: gp_Dir, Angle: float) -> None: ...
	@overload
	def Set(self, Eye: gp_Pnt) -> None: ...
	@overload
	def Set(self, Eye: gp_Pnt, Angle: float) -> None: ...
	@overload
	def Set(self, A: Adaptor2d_HCurve2d) -> None: ...
	def Surface(self) -> Adaptor3d_HSurface: ...
	def Valpoint(self, Index: int) -> gp_Pnt: ...
	def Value(self, X: float) -> Tuple[bool, float]: ...
	def Values(self, X: float) -> Tuple[bool, float, float]: ...

class Contap_ContAna:
	def __init__(self) -> None: ...
	def Circle(self) -> gp_Circ: ...
	def IsDone(self) -> bool: ...
	def Line(self, Index: int) -> gp_Lin: ...
	def NbContours(self) -> int: ...
	@overload
	def Perform(self, S: gp_Sphere, D: gp_Dir) -> None: ...
	@overload
	def Perform(self, S: gp_Sphere, D: gp_Dir, Ang: float) -> None: ...
	@overload
	def Perform(self, S: gp_Sphere, Eye: gp_Pnt) -> None: ...
	@overload
	def Perform(self, C: gp_Cylinder, D: gp_Dir) -> None: ...
	@overload
	def Perform(self, C: gp_Cylinder, D: gp_Dir, Ang: float) -> None: ...
	@overload
	def Perform(self, C: gp_Cylinder, Eye: gp_Pnt) -> None: ...
	@overload
	def Perform(self, C: gp_Cone, D: gp_Dir) -> None: ...
	@overload
	def Perform(self, C: gp_Cone, D: gp_Dir, Ang: float) -> None: ...
	@overload
	def Perform(self, C: gp_Cone, Eye: gp_Pnt) -> None: ...
	def TypeContour(self) -> GeomAbs_CurveType: ...

class Contap_Contour:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Direction: gp_Vec) -> None: ...
	@overload
	def __init__(self, Direction: gp_Vec, Angle: float) -> None: ...
	@overload
	def __init__(self, Eye: gp_Pnt) -> None: ...
	@overload
	def __init__(self, Surf: Adaptor3d_HSurface, Domain: Adaptor3d_TopolTool, Direction: gp_Vec) -> None: ...
	@overload
	def __init__(self, Surf: Adaptor3d_HSurface, Domain: Adaptor3d_TopolTool, Direction: gp_Vec, Angle: float) -> None: ...
	@overload
	def __init__(self, Surf: Adaptor3d_HSurface, Domain: Adaptor3d_TopolTool, Eye: gp_Pnt) -> None: ...
	@overload
	def Init(self, Direction: gp_Vec) -> None: ...
	@overload
	def Init(self, Direction: gp_Vec, Angle: float) -> None: ...
	@overload
	def Init(self, Eye: gp_Pnt) -> None: ...
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Line(self, Index: int) -> Contap_Line: ...
	def NbLines(self) -> int: ...
	@overload
	def Perform(self, Surf: Adaptor3d_HSurface, Domain: Adaptor3d_TopolTool) -> None: ...
	@overload
	def Perform(self, Surf: Adaptor3d_HSurface, Domain: Adaptor3d_TopolTool, Direction: gp_Vec) -> None: ...
	@overload
	def Perform(self, Surf: Adaptor3d_HSurface, Domain: Adaptor3d_TopolTool, Direction: gp_Vec, Angle: float) -> None: ...
	@overload
	def Perform(self, Surf: Adaptor3d_HSurface, Domain: Adaptor3d_TopolTool, Eye: gp_Pnt) -> None: ...
	def SurfaceFunction(self) -> Contap_SurfFunction: ...

class Contap_HContTool:
	@staticmethod
	def Bounds(C: Adaptor2d_HCurve2d) -> Tuple[float, float]: ...
	@staticmethod
	def HasBeenSeen(C: Adaptor2d_HCurve2d) -> bool: ...
	@staticmethod
	def HasFirstPoint(C: Adaptor2d_HCurve2d, Index: int) -> Tuple[bool, int]: ...
	@staticmethod
	def HasLastPoint(C: Adaptor2d_HCurve2d, Index: int) -> Tuple[bool, int]: ...
	@staticmethod
	def IsAllSolution(C: Adaptor2d_HCurve2d) -> bool: ...
	@staticmethod
	def IsVertex(C: Adaptor2d_HCurve2d, Index: int) -> bool: ...
	@staticmethod
	def NbPoints(C: Adaptor2d_HCurve2d) -> int: ...
	@staticmethod
	def NbSamplePoints(S: Adaptor3d_HSurface) -> int: ...
	@staticmethod
	def NbSamplesOnArc(A: Adaptor2d_HCurve2d) -> int: ...
	@staticmethod
	def NbSamplesU(S: Adaptor3d_HSurface, u1: float, u2: float) -> int: ...
	@staticmethod
	def NbSamplesV(S: Adaptor3d_HSurface, v1: float, v2: float) -> int: ...
	@staticmethod
	def NbSegments(C: Adaptor2d_HCurve2d) -> int: ...
	@staticmethod
	def Parameter(V: Adaptor3d_HVertex, C: Adaptor2d_HCurve2d) -> float: ...
	@staticmethod
	def Project(C: Adaptor2d_HCurve2d, P: gp_Pnt2d, Ptproj: gp_Pnt2d) -> Tuple[bool, float]: ...
	@staticmethod
	def SamplePoint(S: Adaptor3d_HSurface, Index: int) -> Tuple[float, float]: ...
	@staticmethod
	def Tolerance(V: Adaptor3d_HVertex, C: Adaptor2d_HCurve2d) -> float: ...
	@staticmethod
	def Value(C: Adaptor2d_HCurve2d, Index: int, Pt: gp_Pnt) -> Tuple[float, float]: ...
	@staticmethod
	def Vertex(C: Adaptor2d_HCurve2d, Index: int, V: Adaptor3d_HVertex) -> None: ...

class Contap_HCurve2dTool:
	@staticmethod
	def BSpline(C: Adaptor2d_HCurve2d) -> Geom2d_BSplineCurve: ...
	@staticmethod
	def Bezier(C: Adaptor2d_HCurve2d) -> Geom2d_BezierCurve: ...
	@staticmethod
	def Circle(C: Adaptor2d_HCurve2d) -> gp_Circ2d: ...
	@staticmethod
	def Continuity(C: Adaptor2d_HCurve2d) -> GeomAbs_Shape: ...
	@staticmethod
	def D0(C: Adaptor2d_HCurve2d, U: float, P: gp_Pnt2d) -> None: ...
	@staticmethod
	def D1(C: Adaptor2d_HCurve2d, U: float, P: gp_Pnt2d, V: gp_Vec2d) -> None: ...
	@staticmethod
	def D2(C: Adaptor2d_HCurve2d, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@staticmethod
	def D3(C: Adaptor2d_HCurve2d, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	@staticmethod
	def DN(C: Adaptor2d_HCurve2d, U: float, N: int) -> gp_Vec2d: ...
	@staticmethod
	def Ellipse(C: Adaptor2d_HCurve2d) -> gp_Elips2d: ...
	@staticmethod
	def FirstParameter(C: Adaptor2d_HCurve2d) -> float: ...
	@staticmethod
	def GetType(C: Adaptor2d_HCurve2d) -> GeomAbs_CurveType: ...
	@staticmethod
	def Hyperbola(C: Adaptor2d_HCurve2d) -> gp_Hypr2d: ...
	@staticmethod
	def Intervals(C: Adaptor2d_HCurve2d, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	@staticmethod
	def IsClosed(C: Adaptor2d_HCurve2d) -> bool: ...
	@staticmethod
	def IsPeriodic(C: Adaptor2d_HCurve2d) -> bool: ...
	@staticmethod
	def LastParameter(C: Adaptor2d_HCurve2d) -> float: ...
	@staticmethod
	def Line(C: Adaptor2d_HCurve2d) -> gp_Lin2d: ...
	@staticmethod
	def NbIntervals(C: Adaptor2d_HCurve2d, S: GeomAbs_Shape) -> int: ...
	@staticmethod
	def NbSamples(C: Adaptor2d_HCurve2d, U0: float, U1: float) -> int: ...
	@staticmethod
	def Parabola(C: Adaptor2d_HCurve2d) -> gp_Parab2d: ...
	@staticmethod
	def Period(C: Adaptor2d_HCurve2d) -> float: ...
	@staticmethod
	def Resolution(C: Adaptor2d_HCurve2d, R3d: float) -> float: ...
	@staticmethod
	def Value(C: Adaptor2d_HCurve2d, U: float) -> gp_Pnt2d: ...

class Contap_Line:
	def __init__(self) -> None: ...
	@overload
	def Add(self, P: IntSurf_PntOn2S) -> None: ...
	@overload
	def Add(self, P: Contap_Point) -> None: ...
	def Arc(self) -> Adaptor2d_HCurve2d: ...
	def Circle(self) -> gp_Circ: ...
	def Clear(self) -> None: ...
	def Line(self) -> gp_Lin: ...
	def LineOn2S(self) -> IntSurf_LineOn2S: ...
	def NbPnts(self) -> int: ...
	def NbVertex(self) -> int: ...
	def Point(self, Index: int) -> IntSurf_PntOn2S: ...
	def ResetSeqOfVertex(self) -> None: ...
	def SetLineOn2S(self, L: IntSurf_LineOn2S) -> None: ...
	def SetTransitionOnS(self, T: IntSurf_TypeTrans) -> None: ...
	@overload
	def SetValue(self, L: gp_Lin) -> None: ...
	@overload
	def SetValue(self, C: gp_Circ) -> None: ...
	@overload
	def SetValue(self, A: Adaptor2d_HCurve2d) -> None: ...
	def TransitionOnS(self) -> IntSurf_TypeTrans: ...
	def TypeContour(self) -> Contap_IType: ...
	def Vertex(self, Index: int) -> Contap_Point: ...

class Contap_Point:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Pt: gp_Pnt, U: float, V: float) -> None: ...
	def Arc(self) -> Adaptor2d_HCurve2d: ...
	def IsInternal(self) -> bool: ...
	def IsMultiple(self) -> bool: ...
	def IsOnArc(self) -> bool: ...
	def IsVertex(self) -> bool: ...
	def ParameterOnArc(self) -> float: ...
	def ParameterOnLine(self) -> float: ...
	def Parameters(self) -> Tuple[float, float]: ...
	def SetArc(self, A: Adaptor2d_HCurve2d, Param: float, TLine: IntSurf_Transition, TArc: IntSurf_Transition) -> None: ...
	def SetInternal(self) -> None: ...
	def SetMultiple(self) -> None: ...
	def SetParameter(self, Para: float) -> None: ...
	def SetValue(self, Pt: gp_Pnt, U: float, V: float) -> None: ...
	def SetVertex(self, V: Adaptor3d_HVertex) -> None: ...
	def TransitionOnArc(self) -> IntSurf_Transition: ...
	def TransitionOnLine(self) -> IntSurf_Transition: ...
	def Value(self) -> gp_Pnt: ...
	def Vertex(self) -> Adaptor3d_HVertex: ...

class Contap_SurfFunction(math_FunctionSetWithDerivatives):
	def __init__(self) -> None: ...
	def Angle(self) -> float: ...
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def Direction(self) -> gp_Dir: ...
	def Direction2d(self) -> gp_Dir2d: ...
	def Direction3d(self) -> gp_Vec: ...
	def Eye(self) -> gp_Pnt: ...
	def FunctionType(self) -> Contap_TFunction: ...
	def IsTangent(self) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def PSurface(self) -> Adaptor3d_HSurface: ...
	def Point(self) -> gp_Pnt: ...
	def Root(self) -> float: ...
	@overload
	def Set(self, S: Adaptor3d_HSurface) -> None: ...
	@overload
	def Set(self, Eye: gp_Pnt) -> None: ...
	@overload
	def Set(self, Dir: gp_Dir) -> None: ...
	@overload
	def Set(self, Dir: gp_Dir, Angle: float) -> None: ...
	@overload
	def Set(self, Eye: gp_Pnt, Angle: float) -> None: ...
	@overload
	def Set(self, Tolerance: float) -> None: ...
	def Surface(self) -> Adaptor3d_HSurface: ...
	def Tolerance(self) -> float: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class Contap_SurfProps:
	@staticmethod
	def DerivAndNorm(S: Adaptor3d_HSurface, U: float, V: float, P: gp_Pnt, d1u: gp_Vec, d1v: gp_Vec, N: gp_Vec) -> None: ...
	@staticmethod
	def NormAndDn(S: Adaptor3d_HSurface, U: float, V: float, P: gp_Pnt, N: gp_Vec, Dnu: gp_Vec, Dnv: gp_Vec) -> None: ...
	@staticmethod
	def Normale(S: Adaptor3d_HSurface, U: float, V: float, P: gp_Pnt, N: gp_Vec) -> None: ...

class Contap_TheIWLineOfTheIWalking(Standard_Transient):
	def __init__(self, theAllocator: Optional[IntSurf_Allocator] = 0) -> None: ...
	def AddIndexPassing(self, Index: int) -> None: ...
	def AddPoint(self, P: IntSurf_PntOn2S) -> None: ...
	@overload
	def AddStatusFirst(self, Closed: bool, HasFirst: bool) -> None: ...
	@overload
	def AddStatusFirst(self, Closed: bool, HasLast: bool, Index: int, P: IntSurf_PathPoint) -> None: ...
	def AddStatusFirstLast(self, Closed: bool, HasFirst: bool, HasLast: bool) -> None: ...
	@overload
	def AddStatusLast(self, HasLast: bool) -> None: ...
	@overload
	def AddStatusLast(self, HasLast: bool, Index: int, P: IntSurf_PathPoint) -> None: ...
	def Cut(self, Index: int) -> None: ...
	def FirstPoint(self) -> IntSurf_PathPoint: ...
	def FirstPointIndex(self) -> int: ...
	def HasFirstPoint(self) -> bool: ...
	def HasLastPoint(self) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsTangentAtBegining(self) -> bool: ...
	def IsTangentAtEnd(self) -> bool: ...
	def LastPoint(self) -> IntSurf_PathPoint: ...
	def LastPointIndex(self) -> int: ...
	def Line(self) -> IntSurf_LineOn2S: ...
	def NbPassingPoint(self) -> int: ...
	def NbPoints(self) -> int: ...
	def PassingPoint(self, Index: int) -> Tuple[int, int]: ...
	def Reverse(self) -> None: ...
	def SetTangencyAtBegining(self, IsTangent: bool) -> None: ...
	def SetTangencyAtEnd(self, IsTangent: bool) -> None: ...
	def SetTangentVector(self, V: gp_Vec, Index: int) -> None: ...
	def TangentVector(self) -> Tuple[gp_Vec, int]: ...
	def Value(self, Index: int) -> IntSurf_PntOn2S: ...

class Contap_TheIWalking:
	def __init__(self, Epsilon: float, Deflection: float, Step: float, theToFillHoles: Optional[bool] = False) -> None: ...
	def IsDone(self) -> bool: ...
	def NbLines(self) -> int: ...
	def NbSinglePnts(self) -> int: ...
	@overload
	def Perform(self, Pnts1: IntSurf_SequenceOfPathPoint, Pnts2: IntSurf_SequenceOfInteriorPoint, Func: Contap_SurfFunction, S: Adaptor3d_HSurface, Reversed: Optional[bool] = False) -> None: ...
	@overload
	def Perform(self, Pnts1: IntSurf_SequenceOfPathPoint, Func: Contap_SurfFunction, S: Adaptor3d_HSurface, Reversed: Optional[bool] = False) -> None: ...
	def SetTolerance(self, Epsilon: float, Deflection: float, Step: float) -> None: ...
	def SinglePnt(self, Index: int) -> IntSurf_PathPoint: ...
	def Value(self, Index: int) -> Contap_TheIWLineOfTheIWalking: ...

class Contap_ThePathPointOfTheSearch:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, Tol: float, V: Adaptor3d_HVertex, A: Adaptor2d_HCurve2d, Parameter: float) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, Tol: float, A: Adaptor2d_HCurve2d, Parameter: float) -> None: ...
	def Arc(self) -> Adaptor2d_HCurve2d: ...
	def IsNew(self) -> bool: ...
	def Parameter(self) -> float: ...
	@overload
	def SetValue(self, P: gp_Pnt, Tol: float, V: Adaptor3d_HVertex, A: Adaptor2d_HCurve2d, Parameter: float) -> None: ...
	@overload
	def SetValue(self, P: gp_Pnt, Tol: float, A: Adaptor2d_HCurve2d, Parameter: float) -> None: ...
	def Tolerance(self) -> float: ...
	def Value(self) -> gp_Pnt: ...
	def Vertex(self) -> Adaptor3d_HVertex: ...

class Contap_TheSearch:
	def __init__(self) -> None: ...
	def AllArcSolution(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def NbSegments(self) -> int: ...
	def Perform(self, F: Contap_ArcFunction, Domain: Adaptor3d_TopolTool, TolBoundary: float, TolTangency: float, RecheckOnRegularity: Optional[bool] = False) -> None: ...
	def Point(self, Index: int) -> Contap_ThePathPointOfTheSearch: ...
	def Segment(self, Index: int) -> Contap_TheSegmentOfTheSearch: ...

class Contap_TheSearchInside:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: Contap_SurfFunction, Surf: Adaptor3d_HSurface, T: Adaptor3d_TopolTool, Epsilon: float) -> None: ...
	def IsDone(self) -> bool: ...
	def NbPoints(self) -> int: ...
	@overload
	def Perform(self, F: Contap_SurfFunction, Surf: Adaptor3d_HSurface, T: Adaptor3d_TopolTool, Epsilon: float) -> None: ...
	@overload
	def Perform(self, F: Contap_SurfFunction, Surf: Adaptor3d_HSurface, UStart: float, VStart: float) -> None: ...
	def Value(self, Index: int) -> IntSurf_InteriorPoint: ...

class Contap_TheSegmentOfTheSearch:
	def __init__(self) -> None: ...
	def Curve(self) -> Adaptor2d_HCurve2d: ...
	def FirstPoint(self) -> Contap_ThePathPointOfTheSearch: ...
	def HasFirstPoint(self) -> bool: ...
	def HasLastPoint(self) -> bool: ...
	def LastPoint(self) -> Contap_ThePathPointOfTheSearch: ...
	def SetLimitPoint(self, V: Contap_ThePathPointOfTheSearch, First: bool) -> None: ...
	def SetValue(self, A: Adaptor2d_HCurve2d) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

class Contap_TheHSequenceOfPoint(Contap_TheSequenceOfPoint, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: Contap_TheSequenceOfPoint) -> None: ...
    def Sequence(self) -> Contap_TheSequenceOfPoint: ...
    def Append(self, theSequence: Contap_TheSequenceOfPoint) -> None: ...


Contap_HContTool_Bounds = Contap_HContTool.Bounds
Contap_HContTool_HasBeenSeen = Contap_HContTool.HasBeenSeen
Contap_HContTool_HasFirstPoint = Contap_HContTool.HasFirstPoint
Contap_HContTool_HasLastPoint = Contap_HContTool.HasLastPoint
Contap_HContTool_IsAllSolution = Contap_HContTool.IsAllSolution
Contap_HContTool_IsVertex = Contap_HContTool.IsVertex
Contap_HContTool_NbPoints = Contap_HContTool.NbPoints
Contap_HContTool_NbSamplePoints = Contap_HContTool.NbSamplePoints
Contap_HContTool_NbSamplesOnArc = Contap_HContTool.NbSamplesOnArc
Contap_HContTool_NbSamplesU = Contap_HContTool.NbSamplesU
Contap_HContTool_NbSamplesV = Contap_HContTool.NbSamplesV
Contap_HContTool_NbSegments = Contap_HContTool.NbSegments
Contap_HContTool_Parameter = Contap_HContTool.Parameter
Contap_HContTool_Project = Contap_HContTool.Project
Contap_HContTool_SamplePoint = Contap_HContTool.SamplePoint
Contap_HContTool_Tolerance = Contap_HContTool.Tolerance
Contap_HContTool_Value = Contap_HContTool.Value
Contap_HContTool_Vertex = Contap_HContTool.Vertex
Contap_HCurve2dTool_BSpline = Contap_HCurve2dTool.BSpline
Contap_HCurve2dTool_Bezier = Contap_HCurve2dTool.Bezier
Contap_HCurve2dTool_Circle = Contap_HCurve2dTool.Circle
Contap_HCurve2dTool_Continuity = Contap_HCurve2dTool.Continuity
Contap_HCurve2dTool_D0 = Contap_HCurve2dTool.D0
Contap_HCurve2dTool_D1 = Contap_HCurve2dTool.D1
Contap_HCurve2dTool_D2 = Contap_HCurve2dTool.D2
Contap_HCurve2dTool_D3 = Contap_HCurve2dTool.D3
Contap_HCurve2dTool_DN = Contap_HCurve2dTool.DN
Contap_HCurve2dTool_Ellipse = Contap_HCurve2dTool.Ellipse
Contap_HCurve2dTool_FirstParameter = Contap_HCurve2dTool.FirstParameter
Contap_HCurve2dTool_GetType = Contap_HCurve2dTool.GetType
Contap_HCurve2dTool_Hyperbola = Contap_HCurve2dTool.Hyperbola
Contap_HCurve2dTool_Intervals = Contap_HCurve2dTool.Intervals
Contap_HCurve2dTool_IsClosed = Contap_HCurve2dTool.IsClosed
Contap_HCurve2dTool_IsPeriodic = Contap_HCurve2dTool.IsPeriodic
Contap_HCurve2dTool_LastParameter = Contap_HCurve2dTool.LastParameter
Contap_HCurve2dTool_Line = Contap_HCurve2dTool.Line
Contap_HCurve2dTool_NbIntervals = Contap_HCurve2dTool.NbIntervals
Contap_HCurve2dTool_NbSamples = Contap_HCurve2dTool.NbSamples
Contap_HCurve2dTool_Parabola = Contap_HCurve2dTool.Parabola
Contap_HCurve2dTool_Period = Contap_HCurve2dTool.Period
Contap_HCurve2dTool_Resolution = Contap_HCurve2dTool.Resolution
Contap_HCurve2dTool_Value = Contap_HCurve2dTool.Value
Contap_SurfProps_DerivAndNorm = Contap_SurfProps.DerivAndNorm
Contap_SurfProps_NormAndDn = Contap_SurfProps.NormAndDn
Contap_SurfProps_Normale = Contap_SurfProps.Normale



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
ChFi3d module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_chfi3d.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _ChFi3d
else:
    import _ChFi3d

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _ChFi3d.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _ChFi3d.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ChFi3d.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ChFi3d.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _ChFi3d.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _ChFi3d.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _ChFi3d.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _ChFi3d.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _ChFi3d.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _ChFi3d.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ChFi3d.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _ChFi3d.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _ChFi3d.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ChFi3d.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ChFi3d.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ChFi3d.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _ChFi3d.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _ChFi3d:
_ChFi3d.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _ChFi3d.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.BRepAdaptor
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.TopAbs
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TopoDS
import OCC.Core.TopLoc
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor
import OCC.Core.ChFiDS
import OCC.Core.TopTools
import OCC.Core.Law
import OCC.Core.TopOpeBRepBuild
import OCC.Core.TopOpeBRepDS
import OCC.Core.TopOpeBRepTool
import OCC.Core.BRepClass3d
import OCC.Core.IntCurveSurface
import OCC.Core.Intf
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.IntSurf
import OCC.Core.IntCurvesFace
import OCC.Core.TopExp
import OCC.Core.Extrema
import OCC.Core.BRepBlend
import OCC.Core.BlendFunc
import OCC.Core.Convert
import OCC.Core.Blend
import OCC.Core.Approx
import OCC.Core.AppCont
import OCC.Core.AppParCurves
import OCC.Core.AppBlend
import OCC.Core.GeomFill
import OCC.Core.TColGeom

from enum import IntEnum
from OCC.Core.Exception import *

ChFi3d_Rational = _ChFi3d.ChFi3d_Rational
ChFi3d_QuasiAngular = _ChFi3d.ChFi3d_QuasiAngular
ChFi3d_Polynomial = _ChFi3d.ChFi3d_Polynomial


class ChFi3d_FilletShape(IntEnum):
	ChFi3d_Rational = 0
	ChFi3d_QuasiAngular = 1
	ChFi3d_Polynomial = 2
ChFi3d_Rational = ChFi3d_FilletShape.ChFi3d_Rational
ChFi3d_QuasiAngular = ChFi3d_FilletShape.ChFi3d_QuasiAngular
ChFi3d_Polynomial = ChFi3d_FilletShape.ChFi3d_Polynomial

class chfi3d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def ConcaveSide(*args) -> "Standard_Integer":
        r"""
        Returns reversed in or1 and(or) or2 if the concave edge defined by the interior of faces f1 and f2, in the neighbourhood of their boundary e is of the edge opposite to the normal of their surface support. the orientation of faces is not taken into consideration in the calculation. the function returns 0 if the calculation fails (tangence), if not, it returns the number of choice of the fillet or chamfer corresponding to the orientations calculated and to the tangent to the guide line read in e.

        Parameters
        ----------
        S1: BRepAdaptor_Surface
        S2: BRepAdaptor_Surface
        E: TopoDS_Edge
        Or1: TopAbs_Orientation
        Or2: TopAbs_Orientation

        Returns
        -------
        int

        """
        return _ChFi3d.chfi3d_ConcaveSide(*args)

    @staticmethod
    def DefineConnectType(*args) -> "ChFiDS_TypeOfConcavity":
        r"""
        Defines the type of concavity in the edge of connection of two faces.

        Parameters
        ----------
        E: TopoDS_Edge
        F1: TopoDS_Face
        F2: TopoDS_Face
        SinTol: float
        CorrectPoint: bool

        Returns
        -------
        ChFiDS_TypeOfConcavity

        """
        return _ChFi3d.chfi3d_DefineConnectType(*args)

    @staticmethod
    def IsTangentFaces(*args) -> "Standard_Boolean":
        r"""
        Returns true if theedge between theface1 and theface2 is tangent.

        Parameters
        ----------
        theEdge: TopoDS_Edge
        theFace1: TopoDS_Face
        theFace2: TopoDS_Face
        Order: GeomAbs_Shape,optional
        	default value is GeomAbs_G1

        Returns
        -------
        bool

        """
        return _ChFi3d.chfi3d_IsTangentFaces(*args)

    @staticmethod
    def NextSide(*args) -> "void":
        r"""
        Same as concaveside, but the orientations are logically deduced from the result of the call of concaveside on the first pair of faces of the fillet or chamnfer.

        Parameters
        ----------
        Or1: TopAbs_Orientation
        Or2: TopAbs_Orientation
        OrSave1: TopAbs_Orientation
        OrSave2: TopAbs_Orientation
        ChoixSauv: int

        Returns
        -------
        int
        Same as the other nextside, but the calculation is done on an edge only.

        Parameters
        ----------
        Or: TopAbs_Orientation
        OrSave: TopAbs_Orientation
        OrFace: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _ChFi3d.chfi3d_NextSide(*args)

    @staticmethod
    def SameSide(*args) -> "Standard_Boolean":
        r"""
        Enables to determine while processing an angle, if two fillets or chamfers constituting a face have identic or opposed concave edges.

        Parameters
        ----------
        Or: TopAbs_Orientation
        OrSave1: TopAbs_Orientation
        OrSave2: TopAbs_Orientation
        OrFace1: TopAbs_Orientation
        OrFace2: TopAbs_Orientation

        Returns
        -------
        bool

        """
        return _ChFi3d.chfi3d_SameSide(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _ChFi3d.chfi3d_swiginit(self, _ChFi3d.new_chfi3d())
    __swig_destroy__ = _ChFi3d.delete_chfi3d

# Register chfi3d in _ChFi3d:
_ChFi3d.chfi3d_swigregister(chfi3d)

def chfi3d_ConcaveSide(*args) -> "Standard_Integer":
    r"""
    Returns reversed in or1 and(or) or2 if the concave edge defined by the interior of faces f1 and f2, in the neighbourhood of their boundary e is of the edge opposite to the normal of their surface support. the orientation of faces is not taken into consideration in the calculation. the function returns 0 if the calculation fails (tangence), if not, it returns the number of choice of the fillet or chamfer corresponding to the orientations calculated and to the tangent to the guide line read in e.

    Parameters
    ----------
    S1: BRepAdaptor_Surface
    S2: BRepAdaptor_Surface
    E: TopoDS_Edge
    Or1: TopAbs_Orientation
    Or2: TopAbs_Orientation

    Returns
    -------
    int

    """
    return _ChFi3d.chfi3d_ConcaveSide(*args)

def chfi3d_DefineConnectType(*args) -> "ChFiDS_TypeOfConcavity":
    r"""
    Defines the type of concavity in the edge of connection of two faces.

    Parameters
    ----------
    E: TopoDS_Edge
    F1: TopoDS_Face
    F2: TopoDS_Face
    SinTol: float
    CorrectPoint: bool

    Returns
    -------
    ChFiDS_TypeOfConcavity

    """
    return _ChFi3d.chfi3d_DefineConnectType(*args)

def chfi3d_IsTangentFaces(*args) -> "Standard_Boolean":
    r"""
    Returns true if theedge between theface1 and theface2 is tangent.

    Parameters
    ----------
    theEdge: TopoDS_Edge
    theFace1: TopoDS_Face
    theFace2: TopoDS_Face
    Order: GeomAbs_Shape,optional
    	default value is GeomAbs_G1

    Returns
    -------
    bool

    """
    return _ChFi3d.chfi3d_IsTangentFaces(*args)

def chfi3d_NextSide(*args) -> "void":
    r"""
    Same as concaveside, but the orientations are logically deduced from the result of the call of concaveside on the first pair of faces of the fillet or chamnfer.

    Parameters
    ----------
    Or1: TopAbs_Orientation
    Or2: TopAbs_Orientation
    OrSave1: TopAbs_Orientation
    OrSave2: TopAbs_Orientation
    ChoixSauv: int

    Returns
    -------
    int
    Same as the other nextside, but the calculation is done on an edge only.

    Parameters
    ----------
    Or: TopAbs_Orientation
    OrSave: TopAbs_Orientation
    OrFace: TopAbs_Orientation

    Returns
    -------
    None

    """
    return _ChFi3d.chfi3d_NextSide(*args)

def chfi3d_SameSide(*args) -> "Standard_Boolean":
    r"""
    Enables to determine while processing an angle, if two fillets or chamfers constituting a face have identic or opposed concave edges.

    Parameters
    ----------
    Or: TopAbs_Orientation
    OrSave1: TopAbs_Orientation
    OrSave2: TopAbs_Orientation
    OrFace1: TopAbs_Orientation
    OrFace2: TopAbs_Orientation

    Returns
    -------
    bool

    """
    return _ChFi3d.chfi3d_SameSide(*args)

class ChFi3d_Builder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Abscissa(self, *args) -> "Standard_Real":
        r"""
        Returns the abscissa of the vertex v on the contour of index ic.

        Parameters
        ----------
        IC: int
        V: TopoDS_Vertex

        Returns
        -------
        float

        """
        return _ChFi3d.ChFi3d_Builder_Abscissa(self, *args)

    def BadShape(self, *args) -> "TopoDS_Shape":
        r"""
        If (hasresult()) returns partial result if (!hasresult()).

        Returns
        -------
        TopoDS_Shape

        """
        return _ChFi3d.ChFi3d_Builder_BadShape(self, *args)

    def Builder(self, *args) -> "opencascade::handle< TopOpeBRepBuild_HBuilder >":
        r"""
        Returns the builder of topologic operations.

        Returns
        -------
        opencascade::handle<TopOpeBRepBuild_HBuilder>

        """
        return _ChFi3d.ChFi3d_Builder_Builder(self, *args)

    def Closed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the contour of index ic is closed.

        Parameters
        ----------
        IC: int

        Returns
        -------
        bool

        """
        return _ChFi3d.ChFi3d_Builder_Closed(self, *args)

    def ClosedAndTangent(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the contour of index ic is closed an tangent.

        Parameters
        ----------
        IC: int

        Returns
        -------
        bool

        """
        return _ChFi3d.ChFi3d_Builder_ClosedAndTangent(self, *args)

    def Compute(self, *args) -> "void":
        r"""
        General calculation of geometry on all edges, topologic reconstruction.

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_Builder_Compute(self, *args)

    def ComputedSurface(self, *args) -> "opencascade::handle< Geom_Surface >":
        r"""
        Returns the is'th surface calculated on the contour ic.

        Parameters
        ----------
        IC: int
        IS: int

        Returns
        -------
        opencascade::handle<Geom_Surface>

        """
        return _ChFi3d.ChFi3d_Builder_ComputedSurface(self, *args)

    def Contains(self, *args) -> "Standard_Integer":
        r"""
        Gives the number of the contour containing e or 0 if e does not belong to any contour.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        int
        Gives the number of the contour containing e or 0 if e does not belong to any contour. sets in indexinspine the index of e in the contour if it's found.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        IndexInSpine: int

        """
        return _ChFi3d.ChFi3d_Builder_Contains(self, *args)

    def FaultyContour(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of i'th contour on which the calculation has failed.

        Parameters
        ----------
        I: int

        Returns
        -------
        int

        """
        return _ChFi3d.ChFi3d_Builder_FaultyContour(self, *args)

    def FaultyVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        Returns the iv'th vertex on which the calculation has failed.

        Parameters
        ----------
        IV: int

        Returns
        -------
        TopoDS_Vertex

        """
        return _ChFi3d.ChFi3d_Builder_FaultyVertex(self, *args)

    def FirstVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        Returns the first vertex v of the contour of index ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        TopoDS_Vertex

        """
        return _ChFi3d.ChFi3d_Builder_FirstVertex(self, *args)

    def Generated(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Advanced function for the history.

        Parameters
        ----------
        EouV: TopoDS_Shape

        Returns
        -------
        TopTools_ListOfShape

        """
        return _ChFi3d.ChFi3d_Builder_Generated(self, *args)

    def HasResult(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if a partial result has been calculated.

        Returns
        -------
        bool

        """
        return _ChFi3d.ChFi3d_Builder_HasResult(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the computation is success.

        Returns
        -------
        bool

        """
        return _ChFi3d.ChFi3d_Builder_IsDone(self, *args)

    def LastVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        Returns the last vertex v of the contour of index ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        TopoDS_Vertex

        """
        return _ChFi3d.ChFi3d_Builder_LastVertex(self, *args)

    def Length(self, *args) -> "Standard_Real":
        r"""
        Returns the length of the contour of index ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        float

        """
        return _ChFi3d.ChFi3d_Builder_Length(self, *args)

    def NbComputedSurfaces(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of surfaces calculated on the contour ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        int

        """
        return _ChFi3d.ChFi3d_Builder_NbComputedSurfaces(self, *args)

    def NbElements(self, *args) -> "Standard_Integer":
        r"""
        Gives the number of disjoint contours on which the fillets are calculated.

        Returns
        -------
        int

        """
        return _ChFi3d.ChFi3d_Builder_NbElements(self, *args)

    def NbFaultyContours(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of contours on which the calculation has failed.

        Returns
        -------
        int

        """
        return _ChFi3d.ChFi3d_Builder_NbFaultyContours(self, *args)

    def NbFaultyVertices(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of vertices on which the calculation has failed.

        Returns
        -------
        int

        """
        return _ChFi3d.ChFi3d_Builder_NbFaultyVertices(self, *args)

    def PerformTwoCornerbyInter(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        bool

        """
        return _ChFi3d.ChFi3d_Builder_PerformTwoCornerbyInter(self, *args)

    def RelativeAbscissa(self, *args) -> "Standard_Real":
        r"""
        Returns the relative abscissa([0.,1.]) of the vertex v on the contour of index ic.

        Parameters
        ----------
        IC: int
        V: TopoDS_Vertex

        Returns
        -------
        float

        """
        return _ChFi3d.ChFi3d_Builder_RelativeAbscissa(self, *args)

    def Remove(self, *args) -> "void":
        r"""
        Extracts from the list the contour containing edge e.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_Builder_Remove(self, *args)

    def Reset(self, *args) -> "void":
        r"""
        Reset all results of compute and returns the algorythm in the state of the last acquisition to enable modification of contours or areas.

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_Builder_Reset(self, *args)

    def SetContinuity(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        InternalContinuity: GeomAbs_Shape
        AngularTolerance: float

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_Builder_SetContinuity(self, *args)

    def SetParams(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Tang: float
        Tesp: float
        T2d: float
        TApp3d: float
        TolApp2d: float
        Fleche: float

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_Builder_SetParams(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape":
        r"""
        If (isdone()) makes the result. if (!isdone()).

        Returns
        -------
        TopoDS_Shape

        """
        return _ChFi3d.ChFi3d_Builder_Shape(self, *args)

    def SplitKPart(self, *args) -> "Standard_Boolean":
        r"""
        Method, implemented in the inheritants, calculates the elements of construction of the surface (fillet or chamfer).

        Parameters
        ----------
        Data: ChFiDS_SurfData
        SetData: ChFiDS_SequenceOfSurfData
        Spine: ChFiDS_Spine
        Iedge: int
        S1: Adaptor3d_HSurface
        I1: Adaptor3d_TopolTool
        S2: Adaptor3d_HSurface
        I2: Adaptor3d_TopolTool

        Returns
        -------
        Intf: bool
        Intl: bool

        """
        return _ChFi3d.ChFi3d_Builder_SplitKPart(self, *args)

    def StripeStatus(self, *args) -> "ChFiDS_ErrorStatus":
        r"""
        For the stripe ic ,indication on the cause of failure walkingfailure,twistedsurface,error, ok.

        Parameters
        ----------
        IC: int

        Returns
        -------
        ChFiDS_ErrorStatus

        """
        return _ChFi3d.ChFi3d_Builder_StripeStatus(self, *args)

    def Value(self, *args) -> "opencascade::handle< ChFiDS_Spine >":
        r"""
        Gives the n'th set of edges (contour) if i >nbelements().

        Parameters
        ----------
        I: int

        Returns
        -------
        opencascade::handle<ChFiDS_Spine>

        """
        return _ChFi3d.ChFi3d_Builder_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ChFi3d.delete_ChFi3d_Builder

# Register ChFi3d_Builder in _ChFi3d:
_ChFi3d.ChFi3d_Builder_swigregister(ChFi3d_Builder)

class ChFi3d_SearchSing(OCC.Core.math.math_FunctionWithDerivative):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C1: Geom_Curve
        C2: Geom_Curve

        Returns
        -------
        None

        """
        _ChFi3d.ChFi3d_SearchSing_swiginit(self, _ChFi3d.new_ChFi3d_SearchSing(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _ChFi3d.delete_ChFi3d_SearchSing

# Register ChFi3d_SearchSing in _ChFi3d:
_ChFi3d.ChFi3d_SearchSing_swigregister(ChFi3d_SearchSing)

class ChFi3d_ChBuilder(ChFi3d_Builder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the builder with the shape <s> for the computation of chamfers.

        Parameters
        ----------
        S: TopoDS_Shape
        Ta: float,optional
        	default value is 1.0e-2

        Returns
        -------
        None

        """
        _ChFi3d.ChFi3d_ChBuilder_swiginit(self, _ChFi3d.new_ChFi3d_ChBuilder(*args))

    def Add(self, *args) -> "void":
        r"""
        Initializes a contour with the edge <e> as first (the next are found by propagation ). the two distances (parameters of the chamfer) must be set after. if the edge <e> has more than 2 adjacent faces.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None
        Initializes a new contour with the edge <e> as first (the next are found by propagation ), and the distance <dis> if the edge <e> has more than 2 adjacent faces.

        Parameters
        ----------
        Dis: float
        E: TopoDS_Edge

        Returns
        -------
        None
        Initializes a new contour with the edge <e> as first (the next are found by propagation ), and the distance <dis1> and <dis2> if the edge <e> has more than 2 adjacent faces.

        Parameters
        ----------
        Dis1: float
        Dis2: float
        E: TopoDS_Edge
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_ChBuilder_Add(self, *args)

    def AddDA(self, *args) -> "void":
        r"""
        Initializes a new contour with the edge <e> as first (the next are found by propagation ), and the distance <dis1> and <angle> if the edge <e> has more than 2 adjacent faces.

        Parameters
        ----------
        Dis: float
        Angle: float
        E: TopoDS_Edge
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_ChBuilder_AddDA(self, *args)

    def Dists(self, *args) -> "void":
        r"""
        Gives the distances <dis1> and <dis2> of the fillet contour of index <ic> in the ds.

        Parameters
        ----------
        IC: int

        Returns
        -------
        Dis1: float
        Dis2: float

        """
        return _ChFi3d.ChFi3d_ChBuilder_Dists(self, *args)

    def GetDist(self, *args) -> "void":
        r"""
        Gives the distances <dis> of the fillet contour of index <ic> in the ds.

        Parameters
        ----------
        IC: int

        Returns
        -------
        Dis: float

        """
        return _ChFi3d.ChFi3d_ChBuilder_GetDist(self, *args)

    def GetDistAngle(self, *args) -> "void":
        r"""
        Gives the distances <dis> and <angle> of the fillet contour of index <ic> in the ds.

        Parameters
        ----------
        IC: int

        Returns
        -------
        Dis: float
        Angle: float

        """
        return _ChFi3d.ChFi3d_ChBuilder_GetDistAngle(self, *args)

    def IsChamfer(self, *args) -> "ChFiDS_ChamfMethod":
        r"""
        Renvoi la methode des chanfreins utilisee.

        Parameters
        ----------
        IC: int

        Returns
        -------
        ChFiDS_ChamfMethod

        """
        return _ChFi3d.ChFi3d_ChBuilder_IsChamfer(self, *args)

    def Mode(self, *args) -> "ChFiDS_ChamfMode":
        r"""
        Returns the mode of chamfer used.

        Returns
        -------
        ChFiDS_ChamfMode

        """
        return _ChFi3d.ChFi3d_ChBuilder_Mode(self, *args)

    def NbSurf(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int

        Returns
        -------
        int

        """
        return _ChFi3d.ChFi3d_ChBuilder_NbSurf(self, *args)

    def PerformSurf(self, *args) -> "void":
        r"""
        Methode, implemented in inheritants, calculates the elements of construction of the surface (fillet or chamfer).

        Parameters
        ----------
        Data: ChFiDS_SequenceOfSurfData
        Guide: ChFiDS_HElSpine
        Spine: ChFiDS_Spine
        Choix: int
        S1: BRepAdaptor_HSurface
        I1: Adaptor3d_TopolTool
        S2: BRepAdaptor_HSurface
        I2: Adaptor3d_TopolTool
        MaxStep: float
        Fleche: float
        TolGuide: float
        Inside: bool
        Appro: bool
        Forward: bool
        RecOnS1: bool
        RecOnS2: bool
        Soldep: math_Vector

        Returns
        -------
        First: float
        Last: float
        Intf: int
        Intl: int
        Method, implemented in the inheritants, calculates the elements of construction of the surface (fillet or chamfer) contact edge/face.

        Parameters
        ----------
        Data: ChFiDS_SequenceOfSurfData
        Guide: ChFiDS_HElSpine
        Spine: ChFiDS_Spine
        Choix: int
        S1: BRepAdaptor_HSurface
        I1: Adaptor3d_TopolTool
        PC1: BRepAdaptor_HCurve2d
        Sref1: BRepAdaptor_HSurface
        PCref1: BRepAdaptor_HCurve2d
        S2: BRepAdaptor_HSurface
        I2: Adaptor3d_TopolTool
        Or2: TopAbs_Orientation
        MaxStep: float
        Fleche: float
        TolGuide: float
        Inside: bool
        Appro: bool
        Forward: bool
        RecP: bool
        RecS: bool
        RecRst: bool
        Soldep: math_Vector

        Returns
        -------
        Decroch1: bool
        First: float
        Last: float
        Method, implemented in inheritants, calculates the elements of construction of the surface (fillet or chamfer) contact edge/face.

        Parameters
        ----------
        Data: ChFiDS_SequenceOfSurfData
        Guide: ChFiDS_HElSpine
        Spine: ChFiDS_Spine
        Choix: int
        S1: BRepAdaptor_HSurface
        I1: Adaptor3d_TopolTool
        Or1: TopAbs_Orientation
        S2: BRepAdaptor_HSurface
        I2: Adaptor3d_TopolTool
        PC2: BRepAdaptor_HCurve2d
        Sref2: BRepAdaptor_HSurface
        PCref2: BRepAdaptor_HCurve2d
        MaxStep: float
        Fleche: float
        TolGuide: float
        Inside: bool
        Appro: bool
        Forward: bool
        RecP: bool
        RecS: bool
        RecRst: bool
        Soldep: math_Vector

        Returns
        -------
        Decroch2: bool
        First: float
        Last: float
        Method, implemented in inheritants, calculates the elements of construction of the surface (fillet or chamfer) contact edge/edge.

        Parameters
        ----------
        Data: ChFiDS_SequenceOfSurfData
        Guide: ChFiDS_HElSpine
        Spine: ChFiDS_Spine
        Choix: int
        S1: BRepAdaptor_HSurface
        I1: Adaptor3d_TopolTool
        PC1: BRepAdaptor_HCurve2d
        Sref1: BRepAdaptor_HSurface
        PCref1: BRepAdaptor_HCurve2d
        Or1: TopAbs_Orientation
        S2: BRepAdaptor_HSurface
        I2: Adaptor3d_TopolTool
        PC2: BRepAdaptor_HCurve2d
        Sref2: BRepAdaptor_HSurface
        PCref2: BRepAdaptor_HCurve2d
        Or2: TopAbs_Orientation
        MaxStep: float
        Fleche: float
        TolGuide: float
        Inside: bool
        Appro: bool
        Forward: bool
        RecP1: bool
        RecRst1: bool
        RecP2: bool
        RecRst2: bool
        Soldep: math_Vector

        Returns
        -------
        Decroch1: bool
        Decroch2: bool
        First: float
        Last: float

        """
        return _ChFi3d.ChFi3d_ChBuilder_PerformSurf(self, *args)

    def ResetContour(self, *args) -> "void":
        r"""
        Reset tous rayons du contour ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_ChBuilder_ResetContour(self, *args)

    def Sect(self, *args) -> "opencascade::handle< ChFiDS_SecHArray1 >":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int
        IS: int

        Returns
        -------
        opencascade::handle<ChFiDS_SecHArray1>

        """
        return _ChFi3d.ChFi3d_ChBuilder_Sect(self, *args)

    def SetDist(self, *args) -> "void":
        r"""
        Set the distance <dis> of the fillet contour of index <ic> in the ds with <dis> on <f>. if the face <f> is not one of common faces of an edge of the contour <ic>.

        Parameters
        ----------
        Dis: float
        IC: int
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_ChBuilder_SetDist(self, *args)

    def SetDistAngle(self, *args) -> "void":
        r"""
        Set the distance <dis> and <angle> of the fillet contour of index <ic> in the ds with <dis> on <f>. if the face <f> is not one of common faces of an edge of the contour <ic>.

        Parameters
        ----------
        Dis: float
        Angle: float
        IC: int
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_ChBuilder_SetDistAngle(self, *args)

    def SetDists(self, *args) -> "void":
        r"""
        Set the distances <dis1> and <dis2> of the fillet contour of index <ic> in the ds with <dis1> on <f>. if the face <f> is not one of common faces of an edge of the contour <ic>.

        Parameters
        ----------
        Dis1: float
        Dis2: float
        IC: int
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_ChBuilder_SetDists(self, *args)

    def SetMode(self, *args) -> "void":
        r"""
        Set the mode of shamfer.

        Parameters
        ----------
        theMode: ChFiDS_ChamfMode

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_ChBuilder_SetMode(self, *args)

    def SimulSurf(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Data: ChFiDS_SurfData
        Guide: ChFiDS_HElSpine
        Spine: ChFiDS_Spine
        Choix: int
        S1: BRepAdaptor_HSurface
        I1: Adaptor3d_TopolTool
        PC1: BRepAdaptor_HCurve2d
        Sref1: BRepAdaptor_HSurface
        PCref1: BRepAdaptor_HCurve2d
        S2: BRepAdaptor_HSurface
        I2: Adaptor3d_TopolTool
        Or2: TopAbs_Orientation
        Fleche: float
        TolGuide: float
        Inside: bool
        Appro: bool
        Forward: bool
        RecP: bool
        RecS: bool
        RecRst: bool
        Soldep: math_Vector

        Returns
        -------
        Decroch1: bool
        First: float
        Last: float
        No available documentation.

        Parameters
        ----------
        Data: ChFiDS_SurfData
        Guide: ChFiDS_HElSpine
        Spine: ChFiDS_Spine
        Choix: int
        S1: BRepAdaptor_HSurface
        I1: Adaptor3d_TopolTool
        Or1: TopAbs_Orientation
        S2: BRepAdaptor_HSurface
        I2: Adaptor3d_TopolTool
        PC2: BRepAdaptor_HCurve2d
        Sref2: BRepAdaptor_HSurface
        PCref2: BRepAdaptor_HCurve2d
        Fleche: float
        TolGuide: float
        Inside: bool
        Appro: bool
        Forward: bool
        RecP: bool
        RecS: bool
        RecRst: bool
        Soldep: math_Vector

        Returns
        -------
        Decroch2: bool
        First: float
        Last: float
        No available documentation.

        Parameters
        ----------
        Data: ChFiDS_SurfData
        Guide: ChFiDS_HElSpine
        Spine: ChFiDS_Spine
        Choix: int
        S1: BRepAdaptor_HSurface
        I1: Adaptor3d_TopolTool
        PC1: BRepAdaptor_HCurve2d
        Sref1: BRepAdaptor_HSurface
        PCref1: BRepAdaptor_HCurve2d
        Or1: TopAbs_Orientation
        S2: BRepAdaptor_HSurface
        I2: Adaptor3d_TopolTool
        PC2: BRepAdaptor_HCurve2d
        Sref2: BRepAdaptor_HSurface
        PCref2: BRepAdaptor_HCurve2d
        Or2: TopAbs_Orientation
        Fleche: float
        TolGuide: float
        Inside: bool
        Appro: bool
        Forward: bool
        RecP1: bool
        RecRst1: bool
        RecP2: bool
        RecRst2: bool
        Soldep: math_Vector

        Returns
        -------
        Decroch1: bool
        Decroch2: bool
        First: float
        Last: float

        """
        return _ChFi3d.ChFi3d_ChBuilder_SimulSurf(self, *args)

    def Simulate(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_ChBuilder_Simulate(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ChFi3d.delete_ChFi3d_ChBuilder

# Register ChFi3d_ChBuilder in _ChFi3d:
_ChFi3d.ChFi3d_ChBuilder_swigregister(ChFi3d_ChBuilder)

class ChFi3d_FilBuilder(ChFi3d_Builder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        FShape: ChFi3d_FilletShape,optional
        	default value is ChFi3d_Rational
        Ta: float,optional
        	default value is 1.0e-2

        Returns
        -------
        None

        """
        _ChFi3d.ChFi3d_FilBuilder_swiginit(self, _ChFi3d.new_ChFi3d_FilBuilder(*args))

    def Add(self, *args) -> "void":
        r"""
        Initialisation of a contour with the first edge (the following are found by propagation). attention, you need to start with setradius.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None
        Initialisation of the constant vector the corresponding 1st edge.

        Parameters
        ----------
        Radius: float
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_FilBuilder_Add(self, *args)

    def GetBounds(self, *args) -> "Standard_Boolean":
        r"""
        Returns in first and last les extremities of the part of variable vector framing e, returns false if e is flagged as edge constant.

        Parameters
        ----------
        IC: int
        E: TopoDS_Edge

        Returns
        -------
        First: float
        Last: float

        """
        return _ChFi3d.ChFi3d_FilBuilder_GetBounds(self, *args)

    def GetFilletShape(self, *args) -> "ChFi3d_FilletShape":
        r"""
        Returns the type of fillet surface.

        Returns
        -------
        ChFi3d_FilletShape

        """
        return _ChFi3d.ChFi3d_FilBuilder_GetFilletShape(self, *args)

    def GetLaw(self, *args) -> "opencascade::handle< Law_Function >":
        r"""
        Returns the rule of elementary evolution of the part to variable vector framing e, returns a rule zero if e is flagged as edge constant.

        Parameters
        ----------
        IC: int
        E: TopoDS_Edge

        Returns
        -------
        opencascade::handle<Law_Function>

        """
        return _ChFi3d.ChFi3d_FilBuilder_GetLaw(self, *args)

    def IsConstant(self, *args) -> "Standard_Boolean":
        r"""
        Returns true the contour is flaged as edge constant.

        Parameters
        ----------
        IC: int

        Returns
        -------
        bool
        Returns true e is flagged as edge constant.

        Parameters
        ----------
        IC: int
        E: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _ChFi3d.ChFi3d_FilBuilder_IsConstant(self, *args)

    def NbSurf(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int

        Returns
        -------
        int

        """
        return _ChFi3d.ChFi3d_FilBuilder_NbSurf(self, *args)

    def Radius(self, *args) -> "Standard_Real":
        r"""
        Returns the vector if the contour is flagged as edge constant.

        Parameters
        ----------
        IC: int

        Returns
        -------
        float
        Returns the vector if e is flagged as edge constant.

        Parameters
        ----------
        IC: int
        E: TopoDS_Edge

        Returns
        -------
        float

        """
        return _ChFi3d.ChFi3d_FilBuilder_Radius(self, *args)

    def ResetContour(self, *args) -> "void":
        r"""
        Reset all vectors of contour ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_FilBuilder_ResetContour(self, *args)

    def Sect(self, *args) -> "opencascade::handle< ChFiDS_SecHArray1 >":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int
        IS: int

        Returns
        -------
        opencascade::handle<ChFiDS_SecHArray1>

        """
        return _ChFi3d.ChFi3d_FilBuilder_Sect(self, *args)

    def SetFilletShape(self, *args) -> "void":
        r"""
        Sets the type of fillet surface.

        Parameters
        ----------
        FShape: ChFi3d_FilletShape

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_FilBuilder_SetFilletShape(self, *args)

    def SetLaw(self, *args) -> "void":
        r"""
        Sets the rule of elementary evolution of the part to variable vector framing e.

        Parameters
        ----------
        IC: int
        E: TopoDS_Edge
        L: Law_Function

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_FilBuilder_SetLaw(self, *args)

    def SetRadius(self, *args) -> "void":
        r"""
        Set the radius of the contour of index ic.

        Parameters
        ----------
        C: Law_Function
        IC: int
        IinC: int

        Returns
        -------
        None
        Set a constant on edge e of the contour of index ic. since then e is flagged as constant.

        Parameters
        ----------
        Radius: float
        IC: int
        E: TopoDS_Edge

        Returns
        -------
        None
        Set a vector on vertex v of the contour of index ic.

        Parameters
        ----------
        Radius: float
        IC: int
        V: TopoDS_Vertex

        Returns
        -------
        None
        Set a vertex on the point of parametre u in the edge iinc of the contour of index ic.

        Parameters
        ----------
        UandR: gp_XY
        IC: int
        IinC: int

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_FilBuilder_SetRadius(self, *args)

    def Simulate(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_FilBuilder_Simulate(self, *args)

    def UnSet(self, *args) -> "void":
        r"""
        Extracts the flag constant and the vector of edge e.

        Parameters
        ----------
        IC: int
        E: TopoDS_Edge

        Returns
        -------
        None
        Extracts the vector of the vertex v.

        Parameters
        ----------
        IC: int
        V: TopoDS_Vertex

        Returns
        -------
        None

        """
        return _ChFi3d.ChFi3d_FilBuilder_UnSet(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ChFi3d.delete_ChFi3d_FilBuilder

# Register ChFi3d_FilBuilder in _ChFi3d:
_ChFi3d.ChFi3d_FilBuilder_swigregister(ChFi3d_FilBuilder)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Adaptor3d import *
from OCC.Core.TColStd import *
from OCC.Core.Bnd import *

#the following typedef cannot be wrapped as is
IntPolyh_ArrayOfEdges = NewType('IntPolyh_ArrayOfEdges', Any)
#the following typedef cannot be wrapped as is
IntPolyh_ArrayOfPointNormal = NewType('IntPolyh_ArrayOfPointNormal', Any)
#the following typedef cannot be wrapped as is
IntPolyh_ArrayOfPoints = NewType('IntPolyh_ArrayOfPoints', Any)
#the following typedef cannot be wrapped as is
IntPolyh_ArrayOfSectionLines = NewType('IntPolyh_ArrayOfSectionLines', Any)
#the following typedef cannot be wrapped as is
IntPolyh_ArrayOfTangentZones = NewType('IntPolyh_ArrayOfTangentZones', Any)
#the following typedef cannot be wrapped as is
IntPolyh_ArrayOfTriangles = NewType('IntPolyh_ArrayOfTriangles', Any)
#the following typedef cannot be wrapped as is
IntPolyh_ListIteratorOfListOfCouples = NewType('IntPolyh_ListIteratorOfListOfCouples', Any)
IntPolyh_PMaillageAffinage = NewType('IntPolyh_PMaillageAffinage', IntPolyh_MaillageAffinage)

class IntPolyh_ListOfCouples:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntPolyh_Couple: ...
    def Last(self) -> IntPolyh_Couple: ...
    def Append(self, theItem: IntPolyh_Couple) -> IntPolyh_Couple: ...
    def Prepend(self, theItem: IntPolyh_Couple) -> IntPolyh_Couple: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntPolyh_Couple: ...
    def SetValue(self, theIndex: int, theValue: IntPolyh_Couple) -> None: ...

class IntPolyh_SeqOfStartPoints:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntPolyh_StartPoint: ...
    def Last(self) -> IntPolyh_StartPoint: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntPolyh_StartPoint) -> IntPolyh_StartPoint: ...
    def Prepend(self, theItem: IntPolyh_StartPoint) -> IntPolyh_StartPoint: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntPolyh_StartPoint: ...
    def SetValue(self, theIndex: int, theValue: IntPolyh_StartPoint) -> None: ...

class IntPolyh_Couple:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theTriangle1: int, theTriangle2: int, theAngle: Optional[float] = -2.0) -> None: ...
	def Angle(self) -> float: ...
	def Dump(self, v: int) -> None: ...
	def FirstValue(self) -> int: ...
	def HashCode(self, theUpperBound: int) -> int: ...
	def IsAnalyzed(self) -> bool: ...
	def IsEqual(self, theOther: IntPolyh_Couple) -> bool: ...
	def SecondValue(self) -> int: ...
	def SetAnalyzed(self, theAnalyzed: bool) -> None: ...
	def SetAngle(self, theAngle: float) -> None: ...
	def SetCoupleValue(self, theInd1: int, theInd2: int) -> None: ...

class IntPolyh_CoupleMapHasher:
	@staticmethod
	def HashCode(theCouple: IntPolyh_Couple, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(theCouple1: IntPolyh_Couple, theCouple2: IntPolyh_Couple) -> bool: ...

class IntPolyh_Edge:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, thePoint1: int, thePoint2: int, theTriangle1: int, theTriangle2: int) -> None: ...
	def Dump(self, v: int) -> None: ...
	def FirstPoint(self) -> int: ...
	def FirstTriangle(self) -> int: ...
	def SecondPoint(self) -> int: ...
	def SecondTriangle(self) -> int: ...
	def SetFirstPoint(self, thePoint: int) -> None: ...
	def SetFirstTriangle(self, theTriangle: int) -> None: ...
	def SetSecondPoint(self, thePoint: int) -> None: ...
	def SetSecondTriangle(self, theTriangle: int) -> None: ...

class IntPolyh_Intersection:
	@overload
	def __init__(self, theS1: Adaptor3d_HSurface, theS2: Adaptor3d_HSurface) -> None: ...
	@overload
	def __init__(self, theS1: Adaptor3d_HSurface, theNbSU1: int, theNbSV1: int, theS2: Adaptor3d_HSurface, theNbSU2: int, theNbSV2: int) -> None: ...
	@overload
	def __init__(self, theS1: Adaptor3d_HSurface, theUPars1: TColStd_Array1OfReal, theVPars1: TColStd_Array1OfReal, theS2: Adaptor3d_HSurface, theUPars2: TColStd_Array1OfReal, theVPars2: TColStd_Array1OfReal) -> None: ...
	def GetLinePoint(self, IndexLine: int, IndexPoint: int) -> Tuple[float, float, float, float, float, float, float, float]: ...
	def GetTangentZonePoint(self, IndexLine: int, IndexPoint: int) -> Tuple[float, float, float, float, float, float, float]: ...
	def IsDone(self) -> bool: ...
	def NbPointsInLine(self, IndexLine: int) -> int: ...
	def NbSectionLines(self) -> int: ...
	def NbTangentZones(self) -> int: ...

class IntPolyh_Point:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, x: float, y: float, z: float, u: float, v: float) -> None: ...
	def Add(self, P1: IntPolyh_Point) -> IntPolyh_Point: ...
	def Cross(self, P1: IntPolyh_Point, P2: IntPolyh_Point) -> None: ...
	def Degenerated(self) -> bool: ...
	def Divide(self, rr: float) -> IntPolyh_Point: ...
	def Dot(self, P2: IntPolyh_Point) -> float: ...
	@overload
	def Dump(self) -> None: ...
	@overload
	def Dump(self, i: int) -> None: ...
	def Middle(self, MySurface: Adaptor3d_HSurface, P1: IntPolyh_Point, P2: IntPolyh_Point) -> None: ...
	def Multiplication(self, rr: float) -> IntPolyh_Point: ...
	def PartOfCommon(self) -> int: ...
	def Set(self, x: float, y: float, z: float, u: float, v: float, II: Optional[int] = 1) -> None: ...
	def SetDegenerated(self, theFlag: bool) -> None: ...
	def SetPartOfCommon(self, ii: int) -> None: ...
	def SetU(self, u: float) -> None: ...
	def SetV(self, v: float) -> None: ...
	def SetX(self, x: float) -> None: ...
	def SetY(self, y: float) -> None: ...
	def SetZ(self, z: float) -> None: ...
	def SquareDistance(self, P2: IntPolyh_Point) -> float: ...
	def SquareModulus(self) -> float: ...
	def Sub(self, P1: IntPolyh_Point) -> IntPolyh_Point: ...
	def U(self) -> float: ...
	def V(self) -> float: ...
	def X(self) -> float: ...
	def Y(self) -> float: ...
	def Z(self) -> float: ...

class IntPolyh_PointNormal:
	pass

class IntPolyh_SectionLine:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, nn: int) -> None: ...
	def ChangeValue(self, nn: int) -> IntPolyh_StartPoint: ...
	def Copy(self, Other: IntPolyh_SectionLine) -> IntPolyh_SectionLine: ...
	def Destroy(self) -> None: ...
	def Dump(self) -> None: ...
	def GetN(self) -> int: ...
	def IncrementNbStartPoints(self) -> None: ...
	def Init(self, nn: int) -> None: ...
	def NbStartPoints(self) -> int: ...
	def Prepend(self, SP: IntPolyh_StartPoint) -> None: ...
	def Value(self, nn: int) -> IntPolyh_StartPoint: ...

class IntPolyh_StartPoint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, xx: float, yy: float, zz: float, uu1: float, vv1: float, uu2: float, vv2: float, T1: int, E1: int, LAM1: float, T2: int, E2: int, LAM2: float, List: int) -> None: ...
	def ChainList(self) -> int: ...
	def CheckSameSP(self, SP: IntPolyh_StartPoint) -> int: ...
	@overload
	def Dump(self) -> None: ...
	@overload
	def Dump(self, i: int) -> None: ...
	def E1(self) -> int: ...
	def E2(self) -> int: ...
	def GetAngle(self) -> float: ...
	def GetEdgePoints(self, Triangle: IntPolyh_Triangle) -> Tuple[int, int, int, int]: ...
	def Lambda1(self) -> float: ...
	def Lambda2(self) -> float: ...
	def SetAngle(self, ang: float) -> None: ...
	def SetChainList(self, ChList: int) -> None: ...
	def SetCoupleValue(self, IT1: int, IT2: int) -> None: ...
	def SetEdge1(self, IE1: int) -> None: ...
	def SetEdge2(self, IE2: int) -> None: ...
	def SetLambda1(self, LAM1: float) -> None: ...
	def SetLambda2(self, LAM2: float) -> None: ...
	def SetUV1(self, UU1: float, VV1: float) -> None: ...
	def SetUV2(self, UU2: float, VV2: float) -> None: ...
	def SetXYZ(self, XX: float, YY: float, ZZ: float) -> None: ...
	def T1(self) -> int: ...
	def T2(self) -> int: ...
	def U1(self) -> float: ...
	def U2(self) -> float: ...
	def V1(self) -> float: ...
	def V2(self) -> float: ...
	def X(self) -> float: ...
	def Y(self) -> float: ...
	def Z(self) -> float: ...

class IntPolyh_Tools:
	@staticmethod
	def ComputeDeflection(theSurf: Adaptor3d_HSurface, theUPars: TColStd_Array1OfReal, theVPars: TColStd_Array1OfReal) -> float: ...
	@staticmethod
	def FillArrayOfPointNormal(theSurf: Adaptor3d_HSurface, theUPars: TColStd_Array1OfReal, theVPars: TColStd_Array1OfReal, thePoints: IntPolyh_ArrayOfPointNormal) -> None: ...
	@staticmethod
	def IsEnlargePossible(theSurf: Adaptor3d_HSurface) -> Tuple[bool, bool]: ...
	@staticmethod
	def MakeSampling(theSurf: Adaptor3d_HSurface, theNbSU: int, theNbSV: int, theEnlargeZone: bool, theUPars: TColStd_Array1OfReal, theVPars: TColStd_Array1OfReal) -> None: ...

class IntPolyh_Triangle:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, thePoint1: int, thePoint2: int, thePoint3: int) -> None: ...
	def BoundingBox(self, thePoints: IntPolyh_ArrayOfPoints) -> Bnd_Box: ...
	def ComputeDeflection(self, theSurface: Adaptor3d_HSurface, thePoints: IntPolyh_ArrayOfPoints) -> float: ...
	def Deflection(self) -> float: ...
	def Dump(self, v: int) -> None: ...
	def FirstEdge(self) -> int: ...
	def FirstEdgeOrientation(self) -> int: ...
	def FirstPoint(self) -> int: ...
	def GetEdgeNumber(self, theEdgeIndex: int) -> int: ...
	def GetEdgeOrientation(self, theEdgeIndex: int) -> int: ...
	def GetNextTriangle(self, theTriangle: int, theEdgeNum: int, TEdges: IntPolyh_ArrayOfEdges) -> int: ...
	def HasIntersection(self) -> bool: ...
	def IsDegenerated(self) -> bool: ...
	def IsIntersectionPossible(self) -> bool: ...
	def LinkEdges2Triangle(self, TEdges: IntPolyh_ArrayOfEdges, theEdge1: int, theEdge2: int, theEdge3: int) -> None: ...
	def MiddleRefinement(self, theTriangleNumber: int, theSurface: Adaptor3d_HSurface, TPoints: IntPolyh_ArrayOfPoints, TTriangles: IntPolyh_ArrayOfTriangles, TEdges: IntPolyh_ArrayOfEdges) -> None: ...
	def MultipleMiddleRefinement(self, theRefineCriterion: float, theBox: Bnd_Box, theTriangleNumber: int, theSurface: Adaptor3d_HSurface, TPoints: IntPolyh_ArrayOfPoints, TTriangles: IntPolyh_ArrayOfTriangles, TEdges: IntPolyh_ArrayOfEdges) -> None: ...
	def SecondEdge(self) -> int: ...
	def SecondEdgeOrientation(self) -> int: ...
	def SecondPoint(self) -> int: ...
	def SetDeflection(self, theDeflection: float) -> None: ...
	def SetDegenerated(self, theDegFlag: bool) -> None: ...
	def SetEdge(self, theEdgeIndex: int, theEdgeNumber: int) -> None: ...
	def SetEdgeAndOrientation(self, theEdge: IntPolyh_Edge, theEdgeIndex: int) -> None: ...
	def SetEdgeOrientation(self, theEdgeIndex: int, theEdgeOrientation: int) -> None: ...
	def SetFirstEdge(self, theEdge: int, theEdgeOrientation: int) -> None: ...
	def SetFirstPoint(self, thePoint: int) -> None: ...
	def SetIntersection(self, theInt: bool) -> None: ...
	def SetIntersectionPossible(self, theIP: bool) -> None: ...
	def SetSecondEdge(self, theEdge: int, theEdgeOrientation: int) -> None: ...
	def SetSecondPoint(self, thePoint: int) -> None: ...
	def SetThirdEdge(self, theEdge: int, theEdgeOrientation: int) -> None: ...
	def SetThirdPoint(self, thePoint: int) -> None: ...
	def ThirdEdge(self) -> int: ...
	def ThirdEdgeOrientation(self) -> int: ...
	def ThirdPoint(self) -> int: ...

#classnotwrapped
class IntPolyh_Array: ...

#classnotwrapped
class IntPolyh_MaillageAffinage: ...

# harray1 classes
# harray2 classes
# hsequence classes

IntPolyh_CoupleMapHasher_HashCode = IntPolyh_CoupleMapHasher.HashCode
IntPolyh_CoupleMapHasher_IsEqual = IntPolyh_CoupleMapHasher.IsEqual
IntPolyh_Tools_ComputeDeflection = IntPolyh_Tools.ComputeDeflection
IntPolyh_Tools_FillArrayOfPointNormal = IntPolyh_Tools.FillArrayOfPointNormal
IntPolyh_Tools_IsEnlargePossible = IntPolyh_Tools.IsEnlargePossible
IntPolyh_Tools_MakeSampling = IntPolyh_Tools.MakeSampling
